Stat

Struct Stat 

pub struct Stat<'a> {
    data: FontData<'a>,
}
STAT (Style Attributes Table)

Fields

data: FontData<'a>

Implementations

Source

impl<'a> Stat<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

Major/minor version number. Set to 1.2 for new fonts.

pub fn design_axis_size(&self) -> u16

The size in bytes of each axis record.

pub fn design_axis_count(&self) -> u16

The number of axis records. In a font with an ‘fvar’ table, this value must be greater than or equal to the axisCount value in the ‘fvar’ table. In all fonts, must be greater than zero if axisValueCount is greater than zero.

pub fn design_axes_offset(&self) -> Offset32

Offset in bytes from the beginning of the STAT table to the start of the design axes array. If designAxisCount is zero, set to zero; if designAxisCount is greater than zero, must be greater than zero.

pub fn design_axes(&self) -> Result<&'a [AxisRecord], ReadError>

Attempt to resolve design_axes_offset.

pub fn axis_value_count(&self) -> u16

The number of axis value tables.

pub fn offset_to_axis_value_offsets(&self) -> Nullable<Offset32>

Offset in bytes from the beginning of the STAT table to the start of the design axes value offsets array. If axisValueCount is zero, set to zero; if axisValueCount is greater than zero, must be greater than zero.

pub fn offset_to_axis_values( &self, ) -> Option<Result<AxisValueArray<'a>, ReadError>>

Attempt to resolve offset_to_axis_value_offsets.

pub fn elided_fallback_name_id(&self) -> Option<NameId>

Name ID used as fallback when projection of names into a particular font model produces a subfamily name containing only elidable elements.

pub fn version_byte_range(&self) -> Range<usize>

pub fn design_axis_size_byte_range(&self) -> Range<usize>

pub fn design_axis_count_byte_range(&self) -> Range<usize>

pub fn design_axes_offset_byte_range(&self) -> Range<usize>

pub fn axis_value_count_byte_range(&self) -> Range<usize>

pub fn offset_to_axis_value_offsets_byte_range(&self) -> Range<usize>

pub fn elided_fallback_name_id_byte_range(&self) -> Range<usize>